@@ -1,29 +1,23 @@
 import time
-from typing import  List
-from google.cloud.logging.handlers import CloudLoggingHandler
-from google.cloud.logging.handlers.transports import  BackgroundThreadTransport
-
+from queue import Queue
 from framl.config_model import ConfigModel
 from google.cloud import logging
 from google.cloud.logging.resource import Resource
 
-
 class Logger:
     MESSAGE_VERSION = 1
+    BUFFER_TIME = 10
 
     def __init__(self, app_path: str):
         model_conf_ob = ConfigModel(app_path)
 
         self._model_name = model_conf_ob.get_model_name()
         self._model_version = model_conf_ob.get_model_version()
-        self._logs_buffer: List[dict] = []
+        self._logs_buffer = Queue()
+        self._last_flush_time = time.time()
 
         logging_client = logging.Client(project=model_conf_ob.get_gcp_project_id())
-        transport = BackgroundThreadTransport(logging_client, "foo", 5, 100, 1)
-        my_handler = CloudLoggingHandler(client=logging_client, name="xyz", transport=BackgroundThreadTransport)
-
         self.sd_logger = logging_client.logger("framl.blablacar.com%2F" + self._model_name.replace("-", "_"))
-        self.sd_logger.addHandler(my_handler)
 
         self.log_res = Resource(
             type="api",
@@ -36,6 +30,15 @@ class Logger:
             },
         )
 
+    def flush_logs(self):
+        logs = []
+        for _ in range(self._logs_buffer.qsize()):
+            logs.append(self._logs_buffer.get())
+
+        with self.sd_logger.batch() as batch:
+            for m in logs:
+                batch.log_struct(m, resource=self.log_res)
+
     def add(self, prediction_id: str, model_input: dict, model_output: dict, latency: int):
         full_log = {
             "request_latency_in_ms": latency,
@@ -50,4 +53,7 @@ class Logger:
             "output":                {**model_output}
         }
 
-        self.sd_logger.log_struct(full_log, resource=self.log_res)
\ No newline at end of file
+        self._logs_buffer.put_nowait(full_log)
+        if self._last_flush_time+Logger.BUFFER_TIME <= time.time():
+            self._last_flush_time = time.time()
+            self.flush_logs()
\ No newline at end of file
